@@ -207,6 +207,9 @@ is_host_with_port (const char *address)
   if (strchr (address, ' '))
     return FALSE;
 
+  if (g_str_has_suffix (address, "/"))
+    return TRUE;
+
   split = g_strsplit (address, ":", -1);
   if (g_strv_length (split) == 2)
     port = g_ascii_strtoll (split[1], NULL, 10);
@@ -295,7 +298,7 @@ ephy_embed_utils_normalize_address (const char *input_address)
 
     scheme = g_uri_peek_scheme (address);
 
-    /* Auto-prepend http:// to anything that is not
+    /* Auto-prepend https:// to anything that is not
      * one according to GLib, because it probably will be
      * something like "google.com". Special case localhost(:port)
      * and IP(:port), because GUri, correctly, thinks it is a
@@ -307,7 +310,7 @@ ephy_embed_utils_normalize_address (const char *input_address)
         !g_strcmp0 (scheme, "localhost") ||
         g_hostname_is_ip_address (scheme) ||
         is_host_with_port (address))
-      effective_address = g_strconcat ("http://", address, NULL);
+      effective_address = g_strconcat ("https://", address, NULL);
   }
 
   return effective_address ? effective_address : g_strdup (address);
@@ -326,7 +329,11 @@ ephy_embed_utils_autosearch_address (const char *search_key)
 
   shell = ephy_embed_shell_get_default ();
   manager = ephy_embed_shell_get_search_engine_manager (shell);
-  engine = ephy_search_engine_manager_get_default_engine (manager);
+
+  if (ephy_embed_shell_get_mode (ephy_embed_shell_get_default ()) == EPHY_EMBED_SHELL_MODE_INCOGNITO)
+    engine = ephy_search_engine_manager_get_incognito_engine (manager);
+  else
+    engine = ephy_search_engine_manager_get_default_engine (manager);
   g_assert (engine != NULL);
 
   return ephy_search_engine_build_search_address (engine, search_key);
